@@ -1,5 +1,5 @@
 package HackaMol::Atom;
-$HackaMol::Atom::VERSION = '0.025';
+$HackaMol::Atom::VERSION = '0.026';
 #ABSTRACT: HackaMol Atom Class
 use 5.008;
 use Moose;
@@ -100,6 +100,17 @@ sub change_symbol {
     $self->symbol( _fix_symbol($symbol) );
 }
 
+sub charge {
+    my $self = shift;
+    carp "charge> takes no arguments. returns get_charges(t)" if (@_);
+    if ($self->has_charges){
+      return ( $self->get_charges( $self->t ) );
+    } 
+    else {
+      return 0;
+    }
+}
+
 sub _clean_atom {
     my $self = shift;
     foreach my $clearthis ( map { "clear_$_" } @delta_attrs ) {
@@ -178,7 +189,7 @@ HackaMol::Atom - HackaMol Atom Class
 
 =head1 VERSION
 
-version 0.025
+version 0.026
 
 =head1 SYNOPSIS
 
