@@ -1,5 +1,5 @@
 package HackaMol::Molecule;
-$HackaMol::Molecule::VERSION = '0.025';
+$HackaMol::Molecule::VERSION = '0.026';
 #ABSTRACT: Molecule class for HackaMol
 use 5.008;
 use Moose;
@@ -55,6 +55,20 @@ sub BUILD {
     return;
 }
 
+sub charge {
+  my $self = shift;
+  my $t = $self->t;
+  my $q = 0;
+  if ($self->has_charges){
+    $q = $self->get_charges($t);
+  }
+  if (@_){
+    my $new_q = shift;
+    $self->set_charges($new_q);
+  }
+  return $q;
+}
+
 # need to increase atom bond_count when push
 after 'push_bonds' => sub {
     my $self = shift;
@@ -231,7 +245,7 @@ HackaMol::Molecule - Molecule class for HackaMol
 
 =head1 VERSION
 
-version 0.025
+version 0.026
 
 =head1 SYNOPSIS
 
