@@ -1,5 +1,5 @@
 package HackaMol::Roles::PathRole;
-$HackaMol::Roles::PathRole::VERSION = '0.025';
+$HackaMol::Roles::PathRole::VERSION = '0.026';
 #ABSTRACT:  
 use 5.008;
 use Moose::Role;
@@ -33,7 +33,7 @@ has 'log_fn' => (
     predicate => 'has_log_fn', 
 ); 
 
-has forts => (
+has 'forts' => (
     is       => 'ro',
     isa      => Paths,
     coerce   => 1,
@@ -82,7 +82,7 @@ HackaMol::Roles::PathRole -
 
 =head1 VERSION
 
-version 0.025
+version 0.026
 
 =head1 DESCRIPTION
 
