@@ -1,5 +1,5 @@
 package HackaMol::Roles::PhysVecMVRRole;
-$HackaMol::Roles::PhysVecMVRRole::VERSION = '0.025';
+$HackaMol::Roles::PhysVecMVRRole::VERSION = '0.026';
 # ABSTRACT: Provides the core of HackaMol Atom and Molecule classes.
 use Math::Vector::Real;
 use Math::Trig;
@@ -8,7 +8,7 @@ use Math::Trig;
 use Moose::Role;
 use Carp;
 
-requires '_build_mass';
+requires qw(_build_mass charge);
 
 has 't', is => 'rw', isa => 'Int|ScalarRef', default => 0;
 
@@ -34,6 +34,7 @@ has "$_" => (
     is      => 'ro',
     isa     => 'ArrayRef[Num]',
     default => sub { [] },
+    predicate => 'has_charges',
     handles => {
         "push_$_"   => 'push',
         "get_$_"    => 'get',
@@ -268,12 +269,6 @@ sub inter_dforces {
     return ($dvec);
 }
 
-sub charge {
-    my $self = shift;
-    carp "charge> takes no arguments. returns get_charges(t)" if (@_);
-    return ( $self->get_charges( $self->t ) );
-}
-
 sub xyz {
     my $self = shift;
     carp "xyz> takes no arguments. returns get_coords(t)" if (@_);
@@ -328,7 +323,7 @@ HackaMol::Roles::PhysVecMVRRole - Provides the core of HackaMol Atom and Molecul
 
 =head1 VERSION
 
-version 0.025
+version 0.026
 
 =head1 SYNOPSIS
 
